@@ -25,7 +25,6 @@ watch_path = None
 class AssetReloadWebSocket(tornado.websocket.WebSocketHandler):
     def open(self):
         self.connected_host = self.get_argument('host')
-        self.watched_files = self.request.arguments['file']
         connections.add(self)
         print '%s connected' % self.connected_host
 
@@ -44,9 +43,8 @@ class FileModifiedHandler(watchdog.events.FileSystemEventHandler):
 
         for connected in connections:
             try:
-                if path in connected.watched_files:
-                    connected.write_message(dict(path=path,
-                                                 mimetype=mimetype))
+                connected.write_message(dict(path=path,
+                                             mimetype=mimetype))
             except:
                 logging.error('Error sending message', exc_info=True)
 
