@@ -1,13 +1,19 @@
-function AssetReload(options) {
-    options = options || {};
-
+(function AssetReload() {
     var elements, element, data, i;
-    var port = options.port || '8888';
-    var webSocketUrl = 'ws://localhost:' + port + '/assetreload?file='
-                       + options.filesToWatch.join('&file=')
-                       + '&host=' + window.location.href;
+    var script = document.getElementById('assetreload');
+    var port = 8888;
+    var connected = false;
 
-    var ws = new WebSocket(webSocketUrl);
+    if (script.dataset.port) {
+        port = script.dataset.port;
+    }
+
+    var ws = new WebSocket('ws://localhost:' + port + '/assetreload' +
+                           '?host=' + window.location.href);
+
+    ws.onopen = function() {
+        connected = true;
+    };
 
     ws.onmessage = function(e) {
         data = JSON.parse(e.data);
@@ -28,4 +34,12 @@ function AssetReload(options) {
             element.setAttribute(attr, data.path + '?' + Date.now());
         }
     };
-}
+
+    ws.onclose = function() {
+        if (!connected) {
+            throw new Error('WebSocket connection failed. ' +
+                            'Check that your port is configured correctly ' +
+                            '(currently on ' + port + ')');
+        }
+    };
+})();
